# WorkflowInstanceStatus

Describes the current state of this workflow instance:   - Queued: The workflow is in queue for being processed.   - Processing: The workflow is in process. 

## Enum

* `QUEUED` (value: `'Queued'`)

* `PROCESSING` (value: `'Processing'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


